"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configureCredentialEndpoint = void 0;
const router_1 = require("../../shared/router");
const OpenId4VcIssuerService_1 = require("../OpenId4VcIssuerService");
function configureCredentialEndpoint(router, config) {
    router.post(config.endpointPath, async (request, response, next) => {
        const { agentContext, issuer } = (0, router_1.getRequestContext)(request);
        try {
            const openId4VcIssuerService = agentContext.dependencyManager.resolve(OpenId4VcIssuerService_1.OpenId4VcIssuerService);
            const credentialRequest = request.body;
            const issueCredentialResponse = await openId4VcIssuerService.createCredentialResponse(agentContext, {
                issuer,
                credentialRequest,
            });
            response.json(issueCredentialResponse);
        }
        catch (error) {
            (0, router_1.sendErrorResponse)(response, agentContext.config.logger, 500, 'invalid_request', error);
        }
        // NOTE: if we don't call next, the agentContext session handler will NOT be called
        next();
    });
}
exports.configureCredentialEndpoint = configureCredentialEndpoint;
//# sourceMappingURL=credentialEndpoint.js.map